% rebase('base.tpl')
<style type="text/css">
    .dash-unit {
        height:100%;
    }
</style>
<div class="container">
    <!-- FIRST ROW OF BLOCKS -->
    <div class="row">
        <!-- 404 -->
        <div class="col-sm-12 col-lg-12">
            <div class="dash-unit">
                <dtitle>404</dtitle>
                <hr/>
                <h1>Can't find the file you're looking for!</h1>
            </div>
         </div>
      </div><!-- /row -->
</div><!-- /container -->
